# =====================================
# generator=datazen
# version=3.1.0
# hash=ae681c7c2c1d6ce64d6b0e0799e8ff67
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.4.5"
